package com.gic.haoban.manage.service.dao.mapper;

import com.gic.haoban.manage.service.entity.TabHaobanStaff;
import com.github.pagehelper.Page;
import org.apache.ibatis.annotations.Param;

import java.util.List;

public interface StaffMapper {
    int deleteByPrimaryKey(String staffId);

    int insertSelective(TabHaobanStaff record);

    TabHaobanStaff selectByPrimaryKey(String staffId);

    int updateByPrimaryKeySelective(TabHaobanStaff record);

    TabHaobanStaff selectByNationcodeAndPhoneNumber(@Param("wxEnterpriseId") String wxEnterpriseId, @Param("nationCode") String nationcode, @Param("phoneNumber") String phoneNumber);

    List<TabHaobanStaff> listByIds(@Param("staffIds") List<String> staffIds);

    List<TabHaobanStaff> listByWxUserId(@Param("wxUserId") String wxUserId,@Param("wxEnterpriseId") String wxEnterpriseId);

    List<TabHaobanStaff> listLikeName(@Param("staffName") String staffName, @Param("wxEnterpriseId") String wxEnterpriseId);

    Page<TabHaobanStaff> pageStaff(@Param("staffIds") List<String> staffIds,
                             @Param("activeFlag") Integer activeFlag,
                             @Param("keyword") String keyword,
                             @Param("departmentIds") List<String> departmentIds,
                             @Param("wxEnterpriseId") String wxEnterpriseId,
                             @Param("relationFlag") Integer relationFlag);

    /**
     * 选择用户id和企业标识
     *
     * @param userId         用户id
     * @param wxEnterpriseId wx企业标识
     * @return {@link TabHaobanStaff }
     * @author mozhu
     * @date 2022-01-13 15:05:28
     */
    TabHaobanStaff selectByUserIdAndEnterpriseId(@Param("userId") String userId,
                                                 @Param("wxEnterpriseId") String wxEnterpriseId);

    TabHaobanStaff selectSuperByWxEnterpriseId(@Param("wxEnterpriseId") String wxEnterpriseId);

    List<TabHaobanStaff> listByPhoneNumber(@Param("phoneNumber") String phoneNumber);

    List<TabHaobanStaff> listByUserIdsAndWxEnterpriseId(@Param("userIds") List<String> userIds, @Param("wxEnterpriseId") String wxEnterpriseId);

    int cleanStaff(@Param("wxEnterpriseId") String wxEnterpriseId, @Param("staffIds") List<String> staffIds);

    TabHaobanStaff getWxStaffByOne(@Param("wxEnterpriseId") String wxEnterpriseId);

    List<String> listUserStaffId(@Param("wxEnterpriseId") String wxEnterpriseId, @Param("staffIds") List<String> staffIds);

    List<TabHaobanStaff> listNoStatusStaffIds(@Param("wxEnterpriseId") String wxEnterpriseId, @Param("staffIds") List<String> staffIds);

    TabHaobanStaff getNoStatusByWxUserIds(@Param("wxEnterpriseId") String wxEnterpriseId, @Param("wxUserId") String wxUserId);

    /**
     * 通过开放用户id和wx企业id列表
     *
     * @param openUserIds    开放的用户id
     * @param wxEnterpriseId wx企业标识
     * @return {@link List<TabHaobanStaff> }
     * @author mozhu
     * @date 2021-12-21 16:35:35
     */
    List<TabHaobanStaff> listByOpenUserIdsAndWxEnterpriseId(@Param("openUserIds") List<String> openUserIds,
                                                            @Param("wxEnterpriseId") String wxEnterpriseId);

    /**
     * 用户id wx企业id列表
     *
     * @param wxEnterpriseId wx企业标识
     * @return {@link List<String> }
     * @author mozhu
     * @date 2021-12-21 17:05:58
     */
    List<TabHaobanStaff> listUserIdByWxEnterpriseId(@Param("wxEnterpriseId") String wxEnterpriseId);


    /**
     * 更新开放用户id,用户id
     *
     * @param wxEnterpriseId wx企业标识
     * @param wxUserId       wx用户id
     * @param wxOpenUseId    开放的用户id
     * @return int
     * @author mozhu
     * @date 2021-12-21 17:17:51
     */
    int updateOpenUserIdsByUserId(@Param("wxEnterpriseId") String wxEnterpriseId,
                                  @Param("wxUserId") String wxUserId,
                                  @Param("wxOpenUseId") String wxOpenUseId);

    /**
     * 选择通过打开用户id和企业标识
     *
     * @param wxOpenUseId    wx开放使用id
     * @param wxEnterpriseId wx企业标识
     * @return {@link TabHaobanStaff }
     * @author mozhu
     * @date 2021-12-21 21:13:56
     */
    TabHaobanStaff selectByOpenUserIdAndEnterpriseId(@Param("wxOpenUseId") String wxOpenUseId,
                                                     @Param("wxEnterpriseId") String wxEnterpriseId);

    /**
     * 更新开放id员工id
     *
     * @param staffId 员工id
     * @param openId  开放id
     * @return int
     */
    int updateOpenIdByStaffId(@Param("staffId") String staffId, @Param("openId") String openId);

    /**
     * 更新二维码通过员工id
     *
     * @param staffId 员工id
     * @param qrCode  二维码
     * @return int
     */
    int updateQrCodeByStaffId(@Param("staffId") String staffId, @Param("qrCode") String qrCode);

    /**
     * 选择电话号码和企业标识
     *
     * @param phoneNumber    电话号码
     * @param wxEnterpriseId wx企业标识
     * @return {@link TabHaobanStaff }
     * @author mozhu
     * @date 2022-01-12 17:20:16
     */
    TabHaobanStaff selectByPhoneNumberAndEnterpriseId(@Param("phoneNumber") String phoneNumber,
                                                      @Param("wxEnterpriseId") String wxEnterpriseId);

    /**
     * 删除同wxUserId的其他staff
     *
     * @param wxUserId       微信用户id
     * @param staffId        导购id
     * @param wxEnterpriseId wx企业标识
     */
    void delOtherStaffByWxUserId(@Param("wxUserId") String wxUserId,
                                 @Param("staffId") String staffId,
                                 @Param("wxEnterpriseId") String wxEnterpriseId);
}